# chrononaut

[![CircleCI](https://circleci.com/gh/onecodex/chrononaut.svg?style=shield&circle-token=0200bf977e97bba9f99e8f036bc61aa41a4b7d5c)](https://circleci.com/gh/onecodex/chrononaut) [![Coverage Status](https://coveralls.io/repos/github/onecodex/chrononaut/badge.svg?t=HnUaG9)](https://coveralls.io/github/onecodex/chrononaut) [![Documentation Status](https://readthedocs.org/projects/chrononaut/badge/?version=latest)](http://chrononaut.readthedocs.io/en/latest/?badge=latest)

A history mixin with audit logging, record locking, and time travel (!) for PostgreSQL and Flask-SQLAlchemy. Requires Flask-SQLAlchemy >= 2.2. See [the documentation](https://chrononaut.readthedocs.io/) for more details.

> _Note: Future plans include extending supporting for SQLAlchemy more generally and across multiple databases._
